@@ -6,7 +6,7 @@
 #include <stdlib.h>
 #include <iostream>
 #include <sys/types.h>
-#include <malloc.h>
+//#include <malloc.h>
 
 class Array {
 protected:
